@@ -44,6 +44,10 @@ class SimpleLoggerV1:
         rslt = self.client.read_holding_registers(40004,6,unit=4).registers
         return self.uint16_to_hex_string(rslt)
         
+    def getType(self):
+        rslt = self.client.read_holding_registers(40010,1,unit=4).registers
+        return rslt[0] 
+
     def getEpoch(self):
         response = self.client.read_holding_registers(40026,2,unit=4)
         return self.uint16_to_uint32(response.registers[0],response.registers[1])
